=== modified file 'NEWS'
--- NEWS	2007-09-11 03:07:14 +0000
+++ NEWS	2007-09-11 08:06:21 +0000
@@ -138,6 +138,9 @@
       changed or deleted, and are copied into the checkout when it is 
       updated.  (Martin Pool, #93856, #93860)
 
+   * Print a warning instead of aborting the ``python setup.py install``
+     process if building of a C extension is not possible.  (Lukáš Lalinský)
+
   IMPROVEMENTS:
 
    * Add the option "--show-diff" to the commit command in order to display

=== modified file 'setup.py'
--- setup.py	2007-09-04 09:10:35 +0000
+++ setup.py	2007-09-11 08:06:21 +0000
@@ -149,6 +149,8 @@
 
 command_classes = {'install_scripts': my_install_scripts,
                    'build': bzr_build}
+from distutils import log
+from distutils.errors import CCompilerError
 from distutils.extension import Extension
 ext_modules = []
 try:
@@ -165,8 +167,20 @@
     from distutils.command.build_ext import build_ext
 else:
     have_pyrex = True
+
+
+class build_ext_if_possible(build_ext):
+
+    def build_extension(self, ext):
+        try:
+            build_ext.build_extension(self, ext)
+        except CCompilerError:
+            log.warn("building of '%s' extension failed, will "
+                     "use the Python version instead" % (ext.name,))
+
+
 # Override the build_ext if we have Pyrex available
-command_classes['build_ext'] = build_ext
+command_classes['build_ext'] = build_ext_if_possible
 unavailable_files = []
 
 
@@ -230,7 +244,7 @@
             # help pages
             'data_files': find_docs(),
             # for building pyrex extensions
-            'cmdclass': {'build_ext': build_ext},
+            'cmdclass': {'build_ext': build_ext_if_possible},
            }
 
     ARGS.update(META_INFO)

